@@ -4,10 +4,12 @@ from django.utils.translation import ugettext_lazy as _
 
 from cms.models.pluginmodel import CMSPlugin
 from cms.models.fields import PageField
-
 from tinymce.models import HTMLField
 from filer.fields.image import FilerImageField
+import djangocms_simple_gallery.south_introspections
+
 from djangocms_simple_gallery import settings
+from djangocms_simple_gallery.validators import fancy_url_validator
 
 import math
 
@@ -43,7 +45,7 @@ class Slide(models.Model):
     title = models.CharField(_('title'), max_length=100, blank=True, null=True)
     description = HTMLField(_('description'), blank=True, null=True)
     page = PageField(verbose_name=_('page'), blank=True, null=True)
-    url = models.URLField(_('url'), blank=True, null=True)
+    url = models.CharField(_('url'), max_length=255, blank=True, null=True, validators=[fancy_url_validator])
 
     class Meta:
         ordering = ['ordering', 'pk',]
